# MP-Contacts

Django contacts app.

### Installation

Install with pip:

```
pip install django-mp-contacts
```


### Requirements

App require this packages:

* django-recaptcha
* django-widget-tweaks
